@@ -31,7 +31,7 @@ fn main() {
   let program_name = args[0].clone();
   let mut opts = Options::new();
   opts.reqopt("i", "input_file_path", "A path to an input CLUSTAL/FASTA/STOCKHOLM file containing the sequence alignment of RNA sequences", "STR");
-  opts.reqopt("o", "output_dir_path", "The path to an output directory", "STR");
+  opts.reqopt("o", "output_dir_path", "A path to an output directory", "STR");
   opts.optopt("", "min_base_pair_prob", &format!("A minimum base-pairing-probability (Uses {} (Turner)/{}(CONTRAfold) by default)", DEFAULT_MIN_BPP, DEFAULT_MIN_BPP_CONTRA), "FLOAT");
   opts.optopt("", "offset_4_max_gap_num", &format!("An offset for maximum numbers of gaps (Uses {} by default)", DEFAULT_OFFSET_4_MAX_GAP_NUM), "UINT");
   opts.optopt("g", "gamma", "A specific gamma parameter rather than a range of gamma parameters", "FLOAT");
@@ -386,6 +386,9 @@ where
   let mut buf_4_writer_2_output_file = format!("# STOCKHOLM 1.0\n");
   let sa_len = sa.cols.len();
   let max_seq_id_len = fasta_records.iter().map(|fasta_record| {fasta_record.fasta_id.len()}).max().unwrap();
+  let descriptor = "#=GC SS_cons";
+  let descriptor_len = descriptor.len();
+  let max_seq_id_len = max_seq_id_len.max(descriptor_len);
   let num_of_rnas = sa.cols[0].len();
   for rna_id in 0 .. num_of_rnas {
     let ref seq_id = fasta_records[rna_id].fasta_id;
@@ -397,8 +400,6 @@ where
     buf_4_writer_2_output_file.push_str(&stockholm_row);
     buf_4_writer_2_output_file.push_str("\n");
   }
-  let descriptor = "#=GC SS_cons";
-  let descriptor_len = descriptor.len();
   buf_4_writer_2_output_file.push_str(descriptor);
   let mut stockholm_row = vec![' ' as Char; max_seq_id_len - descriptor_len + 2];
   let mut mea_css_str = get_mea_css_str(&mea_css, sa_len);
